/**
 * This file is part of common loginstorage for browser and accounts-ui plugins
 *
 * Copyright (c) 2010 Nokia Corporation and/or its subsidiary(-ies).
 * All rights reserved.
 *
 * Contacts: Alberto Mardegan <alberto.mardegan@nokia.com>
 *           Alexander Akimov <ext-alexander.akimov@nokia.com>
 *
 * This software, including documentation, is protected by copyright
 * controlled by Nokia Corporation. All rights are reserved.
 * Copying, including reproducing, storing, adapting or translating,
 * any or all of this material requires the prior written consent of
 * Nokia Corporation. This material also contains confidential
 * information which may not be disclosed to others without the prior
 * written consent of Nokia.
 */

#ifndef LOGINSTORAGE_H
#define LOGINSTORAGE_H

#include <QtSql>
#include <QMap>
#include <QHash>
#include <QString>
#include <QByteArray>
#include <QVariant>
#include <QStringList>
#include <QMetaType>


/*
 * The keys for LoginInfo
 * and column names in logins table
 * */
#define LOGIN_ID                    "id"
#define LOGIN_HOSTNAME              "hostname"
#define LOGIN_HTTP_REALM            "httpRealm"
#define LOGIN_FORM_SUBMIT_URL       "formSubmitURL"
#define LOGIN_USERNAME_FIELD        "usernameField"
#define LOGIN_PASSWORD_FIELD        "passwordField"
#define LOGIN_USERNAME              "username"
#define LOGIN_PASSWORD              "password"
#define LOGIN_GUID                  "guid"
#define LOGIN_CREDENTIALS_ID        "credentialsId"
#define LOGIN_TIME_CREATED          "timeCreated"
#define LOGIN_TIME_LAST_USED        "timeLastUsed"
#define LOGIN_TIME_PASSWORD_CHANGED "timePasswordChanged"
#define LOGIN_TIMES_USED            "timesUsed"
#define LOGINS_TABLE                "logins"

/*
 * the column names in disabledHosts table
 * */
#define HOST_ID       "id"
#define HOST_HOSTNAME "hostname"
#define HOSTS_TABLE   "disabledHosts"

namespace AccountsLoginStorage {

typedef QMap<QByteArray, QVariant> LoginInfo;

class LoginStorage
{

public:
    LoginStorage();
    virtual ~LoginStorage();

    bool init();
    bool removeLogin(const LoginInfo &login);
    bool removeLoginByGUID(const QString &guid);
    bool removeAllLogins();

    QList<LoginInfo> getAllLogins();
    quint32 getLoginCredentialsId(const QString &loginGuid);

    QList<LoginInfo> searchLogins(QHash<QByteArray, QVariant> &matchData);
    quint32 countLogins(QHash<QByteArray, QVariant> &matchData);

    QStringList getAllDisabledHosts();
    bool getLoginSavingEnabled(const QString &host);
    bool setLoginSavingEnabled(const QString &host, bool enabled);

    bool modifyLogin(LoginInfo &oldLogin, LoginInfo &newLogin);
    bool addLogin(LoginInfo &login, quint32 credentialsId, bool forced = false);
    void listDBContents();
private:
    QSqlDatabase *m_db;
};

} //namespace
#endif // LOGINSTORAGE_H
